*-------------------------------*
*		EU-LFS recoding			*
*-------------------------------*

* Paths should be modified to reflect the actual folder structure
global dofiles "`c(pwd)'"
global raw	   "$dofiles/../raw"		// Data as downloaded from Eurostat
global ready   "$dofiles/../ready"		// Destination folder for files after work


* Creating stata files from EU-LFS

global datas: dir "$raw" dir "*"

	foreach dd in $datas {
		
		if strpos("`dd'","_")==0 continue
		
		local cc =  strlower(substr("`dd'",1,2))
		if "`cc'" <="fr" continue		// Manual break (in case of interruption)
	 
 
		local files: dir "$raw/`dd'" files "*.csv"
		
		foreach ff in `files'{
			
			local cc = substr("`ff'",1,2)
			local yy = substr("`ff'",3,4)
			insheet using "$raw/`dd'/`ff'", clear
			
		save "$ready/LFS_`yy'_`cc'", replace 	
	}
 
	}

	exit

*----------------------------------------------------------------------------*
* Looking at demographic variables (gender, age, marstat, mig, education)	
*----------------------------------------------------------------------------*

global lasty =0
global lastc = "aa"

global files : dir "$ready" files "*.dta"

foreach ff in $files{

	tokenize "`ff'" , parse("_" ".")
	local cc "`5'"
	local yy "`3'"

	if `yy'   <   $lasty continue
	if `yy'   <   $lasty & "`cc'" < "$lastc" continue
	
	use "$ready/`ff'", clear
	
	capture confirm variable age
		if _rc!=0 {
			di as error "variable age missing in `cc', year `yy'"
		}
	
	capture drop fem
	gen fem = sex ==2 if sex !=.
	
	capture drop male
	gen male = 1 - fem 

	capture drop mig
	capture confirm numeric variable countryb
	if _rc==0	gen mig = countryb!=0 if !missing(countryb) 
	if _rc!=0	gen mig = . 
	
	capture confirm variable marstat
	if _rc ==0{
			capture drop marstat_old
			ren marstat   marstat_old
			gen marstat = marstat_old ==2 if !missing(marstat_old)
	}
	else{
		di as error "marital status missing in `cc', year `yy'"
	}
	
	capture drop educ
	gen educ = .

	capture confirm string variable hatlev
	if !_rc{
		replace educ = 1 if hatlev =="L"
	replace educ = 2 if hatlev =="M"
	replace educ = 3 if hatlev =="H"
	}
	else {
		di as error "education missing in `cc', year `yy'"
		}
	
	
	
	capture drop isced??
	gen isced97 = hat97lev if hat97lev !=99
	gen isced11 = hat11lev if hat11lev !=999
	* One of the variables will have only missings in a given year. 
	* Following the classification for levels suggested by Eurostat
	* Education is missing for many countries in 1998
	
	save, replace
	
	global lastc 	"`cc'"
	global lasty 	"`yy'"
}

exit	

*----------------------------------------------------------------------------*	
** Creating household variables (n people , n kids)	
*----------------------------------------------------------------------------*
	
global lasty =0
global lastc = "aa"
	
global files : dir "$ready" files "*.dta"

foreach ff in $files{


	tokenize "`ff'" , parse("_" ".")
	local cc "`5'"
	local yy "`3'"
	
	if `yy'   <   $lasty continue
	if `yy'   <   $lasty & "`cc'" < "$lastc" continue
	
	use "$ready/`ff'", clear
			
	capture drop nkids
	gen nkids = hhnbch5 + hhnbch2 if !inlist(99,hhnbch2,hhnbch5)
	
	capture drop anykids
	gen anykids = nkids>0

	capture drop hhsize
	gen hhsize = hhnbpers - hhnbchld - hhnbold if !inlist(99,hhnbpers,hhnbchld,hhnbold)
		
	capture drop urban
	recode degurba (1/2 = 1 "cities or towns") (3 = 0 "Rural") , gen(urban)
	
	capture drop flag_urba
	gen flag_urba = .
		
	save, replace
	
	global lastc 	"`cc'"
	global lasty 	"`yy'"
}	
	
exit	

*----------------------------------------------------------------------------*
** Creating Labor status variables
*----------------------------------------------------------------------------*

global lasty =0
global lastc = "aa"


global files : dir "$ready" files "*.dta"
 
foreach ff in $files{

	tokenize "`ff'" , parse("_" ".")
	local cc "`5'"
	local yy "`3'"
	
	if `yy'   <   $lasty continue
	if `yy'   <   $lasty & "`cc'" < "$lastc" continue
	
	use "$ready/`ff'", clear
	
	*	Labor market status
	*-------------------------
	
	di as result "LMS"
	capture drop lms
	gen lms=.
	replace lms=1 if ilostat==1 & stapro==3
	replace lms=2 if ilostat==1 & (stapro==0 | stapro==4)		// self or in family business
	replace lms=3 if ilostat==2
	replace lms=4 if inlist(ilostat, 3 , 4) 					// Inactive or military
	label var lms "Labour market situation (main job)"
	label def lms 1 "Wage-employed" 2 "Self-employed" 3 "Unemployed" 4 "Inactive" , replace
	label value lms lms
	
	capture drop work
	recode lms (1 2 = 1 ) (3 4 . = 0) , gen(work)
	
	*Missing data on previous year employment status for some countries/ years
	capture drop previous_lms
	gen previous_lms=.
	replace previous_lms=1 if stapro1y==3
	replace previous_lms=2 if stapro1y==0 | stapro1y==1 | stapro1y==2 | stapro1y==4
	replace previous_lms=3 if wstat1y==2
	replace previous_lms=4 if inrange(wstat1y,3,9)
	label value previous_lms lms
	
	
	*	Occupation
	*-------------------------------------
	di as result "Occupation"	
	if `yy' <= 2010{
		replace is883d = . if is883d ==999
		local isco "is88"
	}

	if `yy' >  2010 {
		capture drop is083d
		clonevar is083d = isco3d if isco3d !=999
		local isco "isco"
			}
	
	capture drop `isco'2d
	gen `isco'2d = floor(`isco'3d/10)
	capture gen `isco'1d = floor(`isco'2d/10)
	
	capture drop previous_`isco'??
	clonevar previous_`isco'3d = `isco'pr3d
	clonevar previous_`isco'1d = `isco'pr1d
	
	
	* Industry
	*-----------------------------------
 	di as result "Industry"
	if `yy' <  2008{
		capture drop nace11
		capture drop previous_nace11
		capture gen nace11 =  na111d
		capture gen previous_nace11 =  na111y1d
		
		local pre ""
		foreach st in  q p{
		if "`st'" =="p" local pre "previous_"
		
		capture tostring `pre'nace11, replace
		replace `pre'nace11 = "" if `pre'nace11 =="9"
		
		capture drop `pre'indus
		gen `pre'indus = .
		
		count if missing(`pre'nace11)
		local n1 = `r(N)'

		if `n1'!=_N {
			replace `pre'indus = 1 if inrange(`pre'nace11,"A","B")
			replace `pre'indus = 2 if inrange(`pre'nace11,"C","E")
			replace `pre'indus = 3 if inrange(`pre'nace11,"F","F")
			replace `pre'indus = 4 if inlist(`pre'nace11,"G","H","I","J","K","O","P")
			replace `pre'indus = 5 if inlist(`pre'nace11,"L","M","N","Q")
		}
		}
		}
	
	if `yy' >=  2008 {
		capture drop nace2
		capture drop previous_nace2
		capture gen nace2 =  nace1d  if nace1d!="9"
		capture gen previous_nace2 =  nace1y1d 
		
		local pre ""
		foreach st in q p{
		if "`st'" =="p" local pre "previous_"
		
		capture tostring `pre'nace2, replace
		replace `pre'nace2 = "" if `pre'nace2 =="9"
		
		capture drop `pre'indus
		gen `pre'indus = .
		
		count if missing(`pre'nace2)
		local n1 = `r(N)'
		if `n1'!=_N {
			replace `pre'indus = 1 if inrange(`pre'nace2,"A","B")
			replace `pre'indus = 2 if inrange(`pre'nace2,"C","E")
			replace `pre'indus = 3 if inrange(`pre'nace2,"F","F")
			replace `pre'indus = 4 if inrange(`pre'nace2,"G","M") | inrange(`pre'nace2,"R","T")
			replace `pre'indus = 5 if inrange(`pre'nace2,"N","Q") | `pre'nace2 == "U"
		}
		}
		}
		
	
	label define indus 1 "Agriculture" 2 "Manufacture" 3 "Construction" 4 "Mkt services" ///
						5 "Non-mkt services" , replace
	label val indus previous_indus indus
	
	
	*	Others
	*------------------------------------------
		di as result "Others"
	capture drop tenure 
	gen tenure=startime
	
	capture drop size50
	gen size50 = sizefirm==13 if sizefirm !=99
	
	set varabbrev off
	capture drop ft
	gen ft = ftpt ==1 if inlist(ftpt,1,2)
	set varabbrev on
	
	capture drop hours
	gen hours = hwusual if hwusual!=99  // variable is right censored at 80
	
	save, replace
	
	global lastc 	"`cc'"
	global lasty 	"`yy'"
	
}	

	exit

*----------------------------------------------------------------------------*
*	Technical 
*----------------------------------------------------------------------------*
global lasty =0
global lastc = "aa"
	
global files : dir "$ready" files "*.dta"

foreach ff in $files{


	tokenize "`ff'" , parse("_" ".")
	local cc "`5'"
	local yy "`3'"
	
	if `yy'   <   $lasty continue
	if `yy'   <   $lasty & "`cc'" < "$lastc" continue
	
	use "$ready/`ff'", clear
			
	capture drop weight?
	capture drop flag_weight?
	
	
	gen weight1 = coeff
	gen flag_weight1 = "Yearly -- individual"

	capture confirm variable coeffq
	if !_rc{
	gen weight2 = coeffq
	gen flag_weight2 = "Quarterly -- individual"
	}

	capture drop pid
	egen pid = group(hhseqnum qhhnum) 

		
	capture drop hid
	clonevar hid = hhnum 
	
	
	capture drop q
	gen q = substr(qhhnum,1,2)
	label var q "Quarter"
	
	capture drop year
	clonevar year = refyear
	
	capture drop nuts2
	gen nuts2 = region

	
	save, replace
	
	global lastc 	"`cc'"
	global lasty 	"`yy'"
}					

		
	
exit
	
